@@ -2,7 +2,6 @@ import collections
 from typing import List, Union, Optional
 
 import numpy as np
-from deeptime.markov._base import MembershipsChapmanKolmogorovValidator
 from scipy.sparse import issparse
 
 from ...base import Estimator
@@ -31,6 +30,10 @@ class MaximumLikelihoodHMM(Estimator):
         This model will be used to initialize the hidden markov model estimation routine. Since it is prone to
         get stuck in local optima, several initializations should be tried and scored and/or one of the available
         initialization heuristics should be applied, if appropriate.
+    lagtime : int
+        Lag parameter used for fitting the HMM.
+
+        Note that this parameter is completely independent from what was used for estimating the initial HMM.
     stride : int or str, optional, default=1
         stride between two lagged trajectories extracted from the input trajectories. Given trajectory s[t], stride
         and lag will result in trajectories
@@ -43,8 +46,6 @@ class MaximumLikelihoodHMM(Estimator):
         Bayesian estimator requires a longer stride in order to have statistically uncorrelated trajectories.
         Setting stride = 'effective' uses the largest neglected timescale as an fit for the correlation time and
         sets the stride accordingly.
-    lagtime : int, optional, default=1
-        Lag parameter used for fitting the HMM
     reversible : bool, optional, default=True
         If True, a prior that enforces reversible transition matrices (detailed balance) is used;
         otherwise, a standard  non-reversible prior is used.
@@ -74,8 +75,8 @@ class MaximumLikelihoodHMM(Estimator):
     _HMMModelStorage = collections.namedtuple('_HMMModelStorage', ['transition_matrix', 'output_model',
                                                                    'initial_distribution'])
 
-    def __init__(self, initial_model: HiddenMarkovModel, stride: Union[int, str] = 1,
-                 lagtime: int = 1, reversible: bool = True, stationary: bool = False,
+    def __init__(self, initial_model: HiddenMarkovModel, lagtime: int, stride: Union[int, str] = 1,
+                 reversible: bool = True, stationary: bool = False,
                  p: Optional[np.ndarray] = None, accuracy: float = 1e-3,
                  maxit: int = 1000, maxit_reversible: int = 100000):
         super().__init__()
@@ -220,7 +221,7 @@ class MaximumLikelihoodHMM(Estimator):
     def initial_model(self, value: HiddenMarkovModel) -> None:
         self._initial_transition_model = value
 
-    def fit(self, dtrajs, initial_model=None, **kwargs):
+    def fit(self, dtrajs, initial_model=None, progress=None, **kwargs):
         r""" Fits a new :class:`HMM <HiddenMarkovModel>` to data.
 
         Parameters
@@ -275,31 +276,40 @@ class MaximumLikelihoodHMM(Estimator):
         tmatrix_nonzeros = hmm_data.transition_matrix.nonzero()
         converged = False
 
-        while not converged and it < self.maxit:
-            loglik = 0.0
-            for obs, gamma, counts in zip(dtrajs, gammas, count_matrices):
-                loglik_update, _ = self._forward_backward(hmm_data, obs, alpha, beta, gamma, counts)
-                loglik += loglik_update
-            assert np.isfinite(loglik), it
+        from deeptime.util.platform import handle_progress_bar
+        progress = handle_progress_bar(progress)
 
-            # convergence check
-            if it > 0:
-                dL = loglik - likelihoods[it - 1]
-                if dL < self.accuracy:
-                    converged = True
+        with progress(total=self.maxit) as prog:
+            while not converged and it < self.maxit:
+                loglik = 0.0
+                for obs, gamma, counts in zip(dtrajs, gammas, count_matrices):
+                    loglik_update, _ = self._forward_backward(hmm_data, obs, alpha, beta, gamma, counts)
+                    loglik += loglik_update
+                assert np.isfinite(loglik), it
 
-            # update model
-            self._update_model(hmm_data, dtrajs, gammas, count_matrices, maxiter=self.maxit_reversible)
+                # convergence check
+                if it > 0:
+                    dL = loglik - likelihoods[it - 1]
+                    if dL < self.accuracy:
+                        converged = True
 
-            # connectivity change check
-            tmatrix_nonzeros_new = hmm_data.transition_matrix.nonzero()
-            if not np.array_equal(tmatrix_nonzeros, tmatrix_nonzeros_new):
-                converged = False  # unset converged
-                tmatrix_nonzeros = tmatrix_nonzeros_new
+                # update model
+                self._update_model(hmm_data, dtrajs, gammas, count_matrices, maxiter=self.maxit_reversible)
 
-            # end of iteration
-            likelihoods[it] = loglik
-            it += 1
+                # connectivity change check
+                tmatrix_nonzeros_new = hmm_data.transition_matrix.nonzero()
+                if not np.array_equal(tmatrix_nonzeros, tmatrix_nonzeros_new):
+                    converged = False  # unset converged
+                    tmatrix_nonzeros = tmatrix_nonzeros_new
+
+                # end of iteration
+                likelihoods[it] = loglik
+                it += 1
+
+                if not converged:
+                    prog.update()
+                else:
+                    prog.total = it - 1
 
         likelihoods = np.resize(likelihoods, it)
 
@@ -412,57 +422,3 @@ class MaximumLikelihoodHMM(Estimator):
         model.initial_distribution[:] = pi
         model.transition_matrix[:] = T
         model.output_model.fit(observations, gammas)
-
-    def chapman_kolmogorov_validator(self, mlags, test_model: HiddenMarkovModel = None):
-        r""" Creates a validator instance which can be used to perform a Chapman-Kolmogorov test.
-
-        Parameters
-        ----------
-        mlags : int or int-array
-            Multiples of lag times for testing the Model, e.g. range(10).
-            A single int will trigger a range, i.e. mlags=10 maps to
-            mlags=range(1, 10). The setting None will choose mlags automatically
-            according to the longest available trajectory.
-        test_model : HiddenMarkovModel, optional, default=None
-            The model that is tested. If not provided, uses this estimator's encapsulated model.
-
-        Returns
-        -------
-        validator : MembershipsChapmanKolmogorovValidator
-            The validator.
-
-        Raises
-        ------
-        AssertionError
-            If test_model is None and this estimator has not been :meth:`fit` on data yet or the output model
-            was not a discrete output model.
-        """
-        test_model = self.fetch_model() if test_model is None else test_model
-        assert test_model is not None, "We need a test model via argument or an estimator which was already" \
-                                       "fit to data."
-        from . import DiscreteOutputModel
-        assert isinstance(test_model.output_model, DiscreteOutputModel), \
-            "Can only perform CKTest for discrete output models"
-        lagtime = test_model.lagtime
-        return MLHMMChapmanKolmogorovValidator(test_model, self, np.eye(test_model.n_hidden_states), lagtime, mlags)
-
-
-def _ck_estimate_model_for_lag(estimator: MaximumLikelihoodHMM, model: HiddenMarkovModel, data, lagtime):
-    from .init.discrete import metastable_from_data
-    initial_model = metastable_from_data(data, n_hidden_states=model.n_hidden_states, lagtime=lagtime,
-                                         stride=estimator.stride, reversible=estimator.reversible,
-                                         stationary=estimator.stationary)
-    estimator = MaximumLikelihoodHMM(initial_model, lagtime=lagtime, reversible=estimator.reversible,
-                                     stationary=estimator.stationary, accuracy=estimator.accuracy,
-                                     maxit=estimator.maxit, maxit_reversible=estimator.maxit_reversible)
-    hmm = estimator.fit(data).fetch_model()
-    return hmm.submodel_largest(dtrajs=data)
-
-
-class MLHMMChapmanKolmogorovValidator(MembershipsChapmanKolmogorovValidator):
-
-    def fit(self, data, n_jobs=1, progress=None, estimate_model_for_lag=None, **kw):
-        if n_jobs != 1:
-            import warnings
-            warnings.warn("Ignoring n_jobs for hmm cktest")
-        return super().fit(data, n_jobs=1, estimate_model_for_lag=_ck_estimate_model_for_lag, progress=progress, **kw)
