@@ -6,7 +6,8 @@ from typing import Optional, List, Union
 
 import numpy as np
 import scipy
-from scipy.sparse import issparse
+from scipy.sparse import issparse, identity
+from scipy.sparse import linalg as spla
 
 from ...base import Model
 from ...covariance import CovarianceModel
@@ -21,6 +22,7 @@ from ...numeric import is_square_matrix, spd_inv_sqrt
 from ...util.decorators import cached_property
 from ...util.matrix import submatrix
 from ...util.types import ensure_array
+from ...util.validation import ChapmanKolmogorovTest, ck_test
 
 
 class MarkovStateModel(Model):
@@ -48,6 +50,10 @@ class MarkovStateModel(Model):
     transition_matrix_tolerance : float, default=1e-8
         The tolerance under which a matrix is still considered a transition matrix (only non-negative elements and
         row sums of 1).
+    lagtime : int, optional, default=None
+        The lagtime of this MSM. If there is a count model, the MSM assumes the lagtime of the count model, otherwise
+        falls back to the lagtime set via this constructor argument or a lagtime of `1` if no lagtime is provided
+        at all.
 
     See Also
     --------
@@ -64,11 +70,12 @@ class MarkovStateModel(Model):
     """
 
     def __init__(self, transition_matrix, stationary_distribution=None, reversible=None,
-                 n_eigenvalues=None, ncv=None, count_model=None, transition_matrix_tolerance=1e-8):
+                 n_eigenvalues=None, ncv=None, count_model=None, transition_matrix_tolerance=1e-8, lagtime=None):
         super().__init__()
         self._is_reversible = reversible
         self._ncv = ncv
         self._transition_matrix_tolerance = transition_matrix_tolerance
+        self._lagtime = lagtime
 
         self.update_transition_matrix(transition_matrix)
 
@@ -204,7 +211,7 @@ class MarkovStateModel(Model):
     @property
     def lagtime(self) -> int:
         r""" The lagtime this model was estimated at. In case no count model was provided, this property defaults
-        to a lagtime of `1`.
+        to the lagtime set in the constructor or a lagtime of :math:`\tau = 1` if it was left `None`.
 
         Returns
         -------
@@ -213,7 +220,7 @@ class MarkovStateModel(Model):
         """
         if self.count_model is not None:
             return self.count_model.lagtime
-        return 1
+        return 1 if self._lagtime is None else self._lagtime
 
     @property
     def transition_matrix(self):
@@ -324,11 +331,11 @@ class MarkovStateModel(Model):
 
     def update_stationary_distribution(self, value: Optional[np.ndarray]):
         r""" Explicitly sets the stationary distribution, re-normalizes """
+        self._invalidate_caches()
         if value is not None:
             self._stationary_distribution = np.copy(value) / np.sum(value)
         else:
             self._stationary_distribution = None
-        self._invalidate_caches()
 
     def _compute_eigenvalues(self, neig):
         """ Conducts the eigenvalue decomposition and stores k eigenvalues """
@@ -353,7 +360,7 @@ class MarkovStateModel(Model):
             if m < neig:
                 # not enough eigenpairs present - recompute:
                 self._compute_eigenvalues(neig)
-        except (AttributeError, TypeError) as e:
+        except (AttributeError, TypeError):
             # no eigendecomposition yet - compute:
             self._compute_eigenvalues(neig)
 
@@ -474,20 +481,19 @@ class MarkovStateModel(Model):
 
     def timescales(self, k=None):
         r"""
-        The relaxation timescales corresponding to the eigenvalues
+        Relaxation timescales corresponding to the eigenvalues.
 
         Parameters
         ----------
-        k : int
-            number of timescales to be returned. By default all available
-            eigenvalues, minus 1.
+        k : int, optional, default=None
+            Number of timescales to be returned. By default, this uses all available eigenvalues except for the
+            first (stationary) eigenvalue.
 
         Returns
         -------
         ts : ndarray(m)
-            relaxation timescales in units of the input trajectory time step,
-            defined by :math:`-\tau / ln | \lambda_i |, i = 2,...,k+1`.
-
+            Relaxation timescales in units of the input trajectory time step,
+            defined by :math:`-\tau / \mathrm{ln} | \lambda_i |, i = 2,...,k+1`.
         """
         if k is None:
             self._ensure_eigenvalues()
@@ -501,6 +507,35 @@ class MarkovStateModel(Model):
         else:
             return ts[1:k + 1]  # exclude the stationary process
 
+    def _transition_matrix_power(self, power):
+        r""" Power of transition matrix, leveraging eigenvalue decomposition if matrix is dense. """
+        assert power >= 0, "Negative powers not supported."
+        if power == 1:
+            return self.transition_matrix
+        if power == 0:
+            transition_matrix = np.eye(self.n_states) if not self.sparse else identity(self.n_states)
+        else:
+            if self.sparse:
+                transition_matrix = self.transition_matrix ** power
+            else:
+                integer_power = np.issubdtype(type(power), np.integer)
+                if integer_power:
+                    ev_pow = np.power(self.eigenvalues(), power)
+                else:
+                    ev_pow = np.real_if_close(self.eigenvalues().astype(complex) ** power)
+                    if np.all(~np.iscomplex(ev_pow)):
+                        ev_pow = ev_pow.astype(self.transition_matrix.dtype)
+                transition_matrix = np.linalg.multi_dot([
+                    self.eigenvectors_right(), np.diag(ev_pow), self.eigenvectors_left()
+                ])
+        return transition_matrix
+
+    @cached_property
+    def is_real(self):
+        r""" Checks if all eigenvalues as well as eigenvectors/functions are real. """
+        return np.all(np.isreal(self.eigenvalues())) and \
+               np.all(np.isreal(self.eigenvectors_left()) & np.isreal(self.eigenvectors_right()))
+
     def propagate(self, p0, k: int):
         r""" Propagates the initial distribution p0 k times
 
@@ -533,19 +568,25 @@ class MarkovStateModel(Model):
         if k == 0:  # simply return p0 normalized
             return p0 / p0.sum()
 
-        # sparse: we most likely don't have a full eigenvalue set, so just propagate
-        if self.sparse:
-            pk = np.array(p0)
-            for i in range(k):
-                pk = self.transition_matrix.T.dot(pk)
-        else:  # dense: employ eigenvalue decomposition
-            self._ensure_eigendecomposition(self.n_states)
-            pk = np.linalg.multi_dot([
-                p0.T, self.eigenvectors_right(), np.diag(np.power(self.eigenvalues(), k)),
-                self.eigenvectors_left()
-            ]).real
+        T = self._transition_matrix_power(k)
+        pk = T.T.dot(np.array(p0))
         return pk / pk.sum()
 
+    def __pow__(self, power):
+        r"""
+
+        Parameters
+        ----------
+        power : int
+            The power to raise to.
+
+        Returns
+        -------
+        propagated_msm : MarkovStateModel
+            A Markov state model with a transition matrix :math:`T^k`, where :math:`k` is the power.
+        """
+        return MarkovStateModel(self._transition_matrix_power(power), lagtime=self.lagtime*power)
+
     ################################################################################
     # Hitting problems
     ################################################################################
@@ -730,7 +771,7 @@ class MarkovStateModel(Model):
         >>> times, acf = M.correlation(a)
         >>>
         >>> import matplotlib.pylab as plt # doctest: +SKIP
-        >>> plt.plot(times, acf)  # doctest: +SKIP
+        >>> plt.plot(times,acf)  # doctest: +SKIP
         """
         # input checking is done in low-level API
         # compute number of tau steps
@@ -1015,6 +1056,39 @@ class MarkovStateModel(Model):
             stop = [stop]
         return sim.trajectory(N=n_steps, start=start, P=transition_matrix, stop=stop, seed=seed)
 
+    def ck_test(self, models, n_metastable_sets, include_lag0=True, err_est=False, progress=None):
+        r""" Validates a model estimated at lag time tau by testing its predictions for longer lag times.
+        This is known as the Chapman-Kolmogorov test as it is based on the Chapman-Kolmogorov equation.
+        The test is performed on metastable sets of states rather than the micro-states themselves.
+
+        Parameters
+        ----------
+        models : list of MarkovStateModel
+            A list of models which were estimated at different and in particular longer lagtimes.
+        n_metastable_sets : int
+            Number of metastable sets, estimated via :meth:`pcca`.
+        include_lag0 : bool, optional, default=True
+            Whether to include a lagtime 0 in the test, which corresponds to an identity transition matrix for MSMs.
+        err_est : bool, optional, default=False
+            Whether to compute errors on observable evaluations of the models in the models parameter.
+        progress : object, optional, default=None
+            Optional progress bar. Tested for tqdm.
+
+        Returns
+        -------
+        ck_test : ChapmanKolmogorovTest
+            A Chapman-Kolmogorov test object that can be used with :meth:`plot_ck_test <deeptime.plots.plot_ck_test>`.
+
+        See Also
+        --------
+        deeptime.util.validation.ck_test
+        """
+        from .._base import MembershipsObservable
+        clustering = self.pcca(n_metastable_sets)
+        observable = MembershipsObservable(self, clustering, initial_distribution=self.stationary_distribution)
+        return ck_test(models, observable, test_model=self, include_lag0=include_lag0, err_est=err_est,
+                       progress=progress)
+
     ################################################################################
     # For general statistics
     ################################################################################
